package com.ruoyi.web.app;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.ruoyi.bst.order.domain.OrderQuery;
import com.ruoyi.bst.order.domain.OrderVO;
import com.ruoyi.bst.order.domain.dto.OrderCalcPrePriceDTO;
import com.ruoyi.bst.order.domain.dto.OrderCreateDTO;
import com.ruoyi.bst.order.domain.vo.OrderPrePriceVO;
import com.ruoyi.bst.order.service.OrderConverter;
import com.ruoyi.bst.order.service.OrderService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;

import io.swagger.annotations.ApiOperation;
import io.swagger.v3.oas.annotations.parameters.RequestBody;

@RestController
@RequestMapping("/app/order")
public class AppOrderController extends BaseController {

    @Autowired
    private OrderService orderService;

    @Autowired
    private OrderConverter orderConverter;

    @ApiOperation("获取我的订单列表")
    @GetMapping("/mineList")
    public TableDataInfo getMineList(OrderQuery query) {
        query.setUserId(getUserId());
        startPage();
        List<OrderVO> list = orderService.selectOrderList(query);
        return getDataTable(list);
    }

    @ApiOperation("获取我的订单详情")
    @GetMapping("/mineDetail")
    public AjaxResult getMineDetail(Long id) {
        OrderQuery query = new OrderQuery();
        query.setId(id);
        query.setUserId(getUserId());
        return success(orderService.selectOne(query));
    }

    @ApiOperation("支付前计算订单价格")
    @GetMapping("/calculatePrice")
    public AjaxResult calculatePrice(@RequestBody @Validated OrderCalcPrePriceDTO dto) {
        OrderPrePriceVO vo = orderConverter.toOrderPrePriceVO(dto);
        if (vo == null) {
            return error("计算价格失败，请检查");
        }
        return success(vo);
    }

    @ApiOperation("下单")
    @PostMapping
    public AjaxResult createOrder(@RequestBody @Validated OrderCreateDTO dto) {
        dto.setUserId(getUserId());
        return success(orderService.createOrder(dto));
    }
    
}
